<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="https://gmpg.org/xfn/11">

	<?php wp_head(); ?>

</head>

<body <?php body_class(); ?>>

<?php wp_body_open(); ?>

<?php 
$theme_instance = CitadelaTheme::get_instance(); 
$header_classes = [];
$site_branding_classes = [];

$sticky_header_desktop = get_theme_mod( 'citadela_setting_stickyHeaderDesktop', 'none' );
$sticky_header_mobile = get_theme_mod( 'citadela_setting_stickyHeaderMobile', 'burger-menu-only' );
$enableStickyMenu = $sticky_header_desktop == 'sticky-header-desktop-full' || $sticky_header_mobile == 'sticky-header-mobile-full';

$hideSitetitleAndTaglineDesktop = get_theme_mod('citadela_setting_hideSitetitleAndTaglineDesktop', 'none' );
if( $hideSitetitleAndTaglineDesktop == 'hide-title-and-tagline' ){
	$site_branding_classes[] = "hide-textlogo-desktop";
}
if( $hideSitetitleAndTaglineDesktop == 'hide-tagline' ){
	$site_branding_classes[] = "hide-tagline-desktop";
}
$hideSitetitleAndTaglineMobile = get_theme_mod('citadela_setting_hideSitetitleAndTaglineMobile', 'none' );
if( $hideSitetitleAndTaglineMobile == 'hide-title-and-tagline' ){
	$site_branding_classes[] = "hide-textlogo-mobile";
}
if( $hideSitetitleAndTaglineMobile == 'hide-tagline' ){
	$site_branding_classes[] = "hide-tagline-mobile";
}

if( $sticky_header_desktop == 'sticky-header-desktop-full' ){
	if( $theme_instance->get_pro_theme_mod( 'citadela_setting_hideSitetitleOnFullStickyDesktop', false ) ){
		$site_branding_classes[] = 'hide-title-desktop';		
	}
}
if( $sticky_header_mobile == 'sticky-header-mobile-full' ){
	if( $theme_instance->get_pro_theme_mod( 'citadela_setting_hideSitetitleOnFullStickyMobile', false ) ){
		$site_branding_classes[] = 'hide-title-mobile';		
	}
}

$logoSpaceMaxWidthDesktop = $theme_instance->get_pro_theme_mod( 'citadela_setting_logoSpaceMaxWidthDesktop', 400 );

$logoImageMaxWidthDesktop = $theme_instance->get_pro_theme_mod( 'citadela_setting_logoImageMaxWidthDesktop', 150 );
$logoImageMaxWidthMobile = $theme_instance->get_pro_theme_mod( 'citadela_setting_logoImageMaxWidthMobile', 150 );
$logoImageMaxWidthMobileData = [];
if( $logoImageMaxWidthMobile ){
	$logoImageMaxWidthMobileData['desktop'] = $logoImageMaxWidthDesktop.'px';
	$logoImageMaxWidthMobileData['mobile'] = $logoImageMaxWidthMobile.'px';
}

$logoFontSizeMobile = $theme_instance->get_pro_theme_mod( 'citadela_setting_logoFontSize', '' );
$logoFontSizeMobileData = [];
if( $logoFontSizeMobile ){
	$logoFontSizeMobileData['desktop'] = '';
	$logoFontSizeMobileData['mobile'] = $logoFontSizeMobile.'em';
}



?>

<div id="page" class="site">
	<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'citadela' ); ?></a>
	<?php
		
		if( get_theme_mod( 'citadela_setting_headerFullwidth' ) ){
			$header_classes[] = 'fullwidth-header';
		}
		if( $theme_instance->get_pro_theme_mod( 'citadela_setting_logoAlignLeftMobile', false ) ){
			$header_classes[] = 'logo-align-left-mobile';
		}

		
	?>
	<?php if( $enableStickyMenu ): ?> 
		<div class="sticky-header-wrapper">
	<?php endif; ?>

		<header id="masthead" class="site-header <?php echo esc_attr( implode(' ', $header_classes ) ); ?>">
			<div class="grid-main">

				<div 
					class="site-branding <?php echo esc_attr( implode(' ', $site_branding_classes ) ); ?>" 
					<?php if( $logoSpaceMaxWidthDesktop ){ echo 'style="max-width:'.$logoSpaceMaxWidthDesktop.'px;"'; } ?>
				>
					<?php if( get_theme_mod( 'custom_logo' ) != "" ): ?>
						<div 
							class="logo-wrapper" 
							<?php if( $logoImageMaxWidthDesktop ){ echo 'style="max-width:'.$logoImageMaxWidthDesktop.'px;"'; } ?>
							<?php if( $logoImageMaxWidthMobileData ){ echo 'data-mobile-max-width="'.htmlspecialchars( json_encode( $logoImageMaxWidthMobileData ) ).'"'; } ?>
							>
							<?php do_action( 'citadela_render_header_logo' );	?>
						</div>
					<?php endif; ?>

					<div class="text-logo">

						<?php
						if ( is_front_page() && is_home() ) :
							?>
							<h1 class="site-title" <?php if( $logoFontSizeMobileData ){ echo 'data-mobile-font-size="'.htmlspecialchars( json_encode( $logoFontSizeMobileData ) ).'"'; } ?>><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
							<?php
						else :
							?>
							<p class="site-title" <?php if( $logoFontSizeMobileData ){ echo 'data-mobile-font-size="'.htmlspecialchars( json_encode( $logoFontSizeMobileData ) ).'"'; } ?>><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
							<?php
						endif;

						if ( get_bloginfo( 'description', 'display' ) || is_customize_preview() ) :
							?>
							<p class="site-description"><?php bloginfo( 'description' ); ?></p>
						<?php endif; ?>
					</div><!-- .text-logo -->
				</div><!-- .site-branding -->

				<nav id="site-navigation" class="main-navigation menu-hidden">
					<?php
					wp_nav_menu( array(
						'theme_location' => 'main-menu',
						'menu_id'        => 'main-menu',
					) );
					?>
				
				<?php do_action( 'citadela_render_woocommerce_minicart' ); ?>
				
				</nav><!-- #site-navigation -->


			</div><!-- .grid-main -->
		</header><!-- #masthead -->

	<?php if( $enableStickyMenu ): ?> 
		</div>
	<?php endif; ?>

	<div id="content" class="site-content">
